pub struct DaysFn;Expand description
Returns the number of whole days between two date serial values.
Remarks
- Result is
end_date - start_date; negative results are allowed. - Fractional serial inputs are truncated to their date portion.
- Serials are interpreted with the Excel 1900 mapping (including the 1900 leap-year bug behavior).
- This function currently does not switch interpretation based on workbook
1900/1904mode.
Examples
title: "Positive day difference"
formula: "=DAYS(45366, 45323)"
expected: 43title: "Negative day difference"
formula: "=DAYS(45323, 45366)"
expected: -43related:
- DATEDIF
- DAYS360
- NETWORKDAYS
faq:
- q: "Does DAYS count partial-day time fractions?"
a: "No. DAYS truncates both serial inputs to whole dates before subtracting end_date - start_date."Trait Implementations
Sourceimpl Function for DaysFn
[formualizer-docgen:schema:start]
Name: DAYS
Type: DaysFn
Min args: 2
Max args: 2
Variadic: false
Signature: DAYS(arg1: number@scalar, arg2: number@scalar)
Arg schema: arg1{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg2{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}
Caps: PURE
[formualizer-docgen:schema:end]
impl Function for DaysFn
[formualizer-docgen:schema:start] Name: DAYS Type: DaysFn Min args: 2 Max args: 2 Variadic: false Signature: DAYS(arg1: number@scalar, arg2: number@scalar) Arg schema: arg1{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg2{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false} Caps: PURE [formualizer-docgen:schema:end]
fn name(&self) -> &'static str
fn min_args(&self) -> usize
fn arg_schema(&self) -> &'static [ArgSchema]
Sourcefn eval<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn eval<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
The unified evaluation path. Read more
fn namespace(&self) -> &'static str
fn variadic(&self) -> bool
fn volatile(&self) -> bool
Sourcefn aliases(&self) -> &'static [&'static str]
fn aliases(&self) -> &'static [&'static str]
Optional list of additional alias names (case-insensitive) that should resolve to this
function. Default: empty slice. Implementors can override to expose legacy names.
Returned slice must have ’static lifetime (typically a static array reference).
fn function_salt(&self) -> u64
Sourcefn eval_reference<'a, 'b, 'c>(
&self,
_args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Option<Result<ReferenceType, ExcelError>>
fn eval_reference<'a, 'b, 'c>( &self, _args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Option<Result<ReferenceType, ExcelError>>
Optional reference result path. Only called by the interpreter/engine
when the callsite expects a reference (e.g., range combinators, by-ref
argument positions, or spill sources). Read more
Sourcefn dispatch<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn dispatch<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
Dispatch to the unified evaluation path with automatic argument validation.