pub struct DevsqFn;Expand description
Returns the sum of squared deviations from the mean.
DEVSQ is useful for variance-related calculations and diagnostics of spread.
Remarks
- Returns
#NUM!when no numeric values are available. - Non-numeric values in referenced ranges are ignored.
- Uses the arithmetic mean of included values.
Examples
title: "Sum of squared deviations from scalar values"
formula: "=DEVSQ(2,4,6)"
expected: 8title: "Sum of squared deviations from a range"
grid:
A1: 1
A2: 2
A3: 3
A4: 4
formula: "=DEVSQ(A1:A4)"
expected: 5Trait Implementations
Sourceimpl Function for DevsqFn
[formualizer-docgen:schema:start]
Name: DEVSQ
Type: DevsqFn
Min args: 1
Max args: variadic
Variadic: true
Signature: DEVSQ(arg1…: number@range)
Arg schema: arg1{kinds=number,required=true,shape=range,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}
Caps: PURE, REDUCTION, NUMERIC_ONLY
[formualizer-docgen:schema:end]
impl Function for DevsqFn
[formualizer-docgen:schema:start] Name: DEVSQ Type: DevsqFn Min args: 1 Max args: variadic Variadic: true Signature: DEVSQ(arg1…: number@range) Arg schema: arg1{kinds=number,required=true,shape=range,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false} Caps: PURE, REDUCTION, NUMERIC_ONLY [formualizer-docgen:schema:end]
fn name(&self) -> &'static str
fn min_args(&self) -> usize
fn variadic(&self) -> bool
fn arg_schema(&self) -> &'static [ArgSchema]
Sourcefn eval<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn eval<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
The unified evaluation path. Read more
fn namespace(&self) -> &'static str
fn volatile(&self) -> bool
Sourcefn aliases(&self) -> &'static [&'static str]
fn aliases(&self) -> &'static [&'static str]
Optional list of additional alias names (case-insensitive) that should resolve to this
function. Default: empty slice. Implementors can override to expose legacy names.
Returned slice must have ’static lifetime (typically a static array reference).
fn function_salt(&self) -> u64
Sourcefn eval_reference<'a, 'b, 'c>(
&self,
_args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Option<Result<ReferenceType, ExcelError>>
fn eval_reference<'a, 'b, 'c>( &self, _args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Option<Result<ReferenceType, ExcelError>>
Optional reference result path. Only called by the interpreter/engine
when the callsite expects a reference (e.g., range combinators, by-ref
argument positions, or spill sources). Read more
Sourcefn dispatch<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn dispatch<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
Dispatch to the unified evaluation path with automatic argument validation.