pub struct MEDIAN;Expand description
Returns the middle value of a numeric data set.
For an even number of values, MEDIAN returns the average of the two center values.
Remarks
- Ignores non-numeric values in referenced ranges.
- Returns
#NUM!when no numeric values are available. - Supports both scalar arguments and range inputs.
Examples
title: "Median of an odd-sized set"
formula: "=MEDIAN(1,3,8)"
expected: 3title: "Median of an even-sized range"
grid:
A1: 1
A2: 2
A3: 10
A4: 12
formula: "=MEDIAN(A1:A4)"
expected: 6related:
- AVERAGE
- MODE.SNGL
- QUARTILE.INC
faq:
- q: "When does MEDIAN return #NUM!?"
a: "MEDIAN returns #NUM! when no numeric values are available after filtering/coercion."Trait Implementations
Sourceimpl Function for MEDIAN
[formualizer-docgen:schema:start]
Name: MEDIAN
Type: MEDIAN
Min args: 1
Max args: variadic
Variadic: true
Signature: MEDIAN(arg1…: number@range)
Arg schema: arg1{kinds=number,required=true,shape=range,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}
Caps: PURE, REDUCTION, NUMERIC_ONLY
[formualizer-docgen:schema:end]
impl Function for MEDIAN
[formualizer-docgen:schema:start] Name: MEDIAN Type: MEDIAN Min args: 1 Max args: variadic Variadic: true Signature: MEDIAN(arg1…: number@range) Arg schema: arg1{kinds=number,required=true,shape=range,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false} Caps: PURE, REDUCTION, NUMERIC_ONLY [formualizer-docgen:schema:end]
fn name(&self) -> &'static str
fn min_args(&self) -> usize
fn variadic(&self) -> bool
fn arg_schema(&self) -> &'static [ArgSchema]
Sourcefn eval<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn eval<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
The unified evaluation path. Read more
fn namespace(&self) -> &'static str
fn volatile(&self) -> bool
Sourcefn aliases(&self) -> &'static [&'static str]
fn aliases(&self) -> &'static [&'static str]
Optional list of additional alias names (case-insensitive) that should resolve to this
function. Default: empty slice. Implementors can override to expose legacy names.
Returned slice must have ’static lifetime (typically a static array reference).
fn function_salt(&self) -> u64
Sourcefn eval_reference<'a, 'b, 'c>(
&self,
_args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Option<Result<ReferenceType, ExcelError>>
fn eval_reference<'a, 'b, 'c>( &self, _args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Option<Result<ReferenceType, ExcelError>>
Optional reference result path. Only called by the interpreter/engine
when the callsite expects a reference (e.g., range combinators, by-ref
argument positions, or spill sources). Read more
Sourcefn dispatch<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn dispatch<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
Dispatch to the unified evaluation path with automatic argument validation.