pub struct PoissonDistFn;Expand description
Returns the Poisson probability for event count x at average rate mean.
POISSON.DIST supports exact-count mode (PMF) and cumulative mode (CDF).
Remarks
xis truncated to an integer and must be at least0.meanmust be non-negative.- Set
cumulativeto non-zero for CDF mode, or0for PMF mode. - Returns
#NUM!for negative counts or negative mean values.
Examples
title: "Poisson PMF for zero events"
formula: "=POISSON.DIST(0,2,FALSE)"
expected: 0.1353352832366127title: "Poisson CDF up to two events"
formula: "=POISSON.DIST(2,2,TRUE)"
expected: 0.6766764161830634Trait Implementations
Sourceimpl Debug for PoissonDistFn
impl Debug for PoissonDistFn
Sourceimpl Function for PoissonDistFn
[formualizer-docgen:schema:start]
Name: POISSON.DIST
Type: PoissonDistFn
Min args: 3
Max args: 3
Variadic: false
Signature: POISSON.DIST(arg1: number@scalar, arg2: number@scalar, arg3: number@scalar)
Arg schema: arg1{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg2{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg3{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}
Caps: PURE
[formualizer-docgen:schema:end]
impl Function for PoissonDistFn
[formualizer-docgen:schema:start] Name: POISSON.DIST Type: PoissonDistFn Min args: 3 Max args: 3 Variadic: false Signature: POISSON.DIST(arg1: number@scalar, arg2: number@scalar, arg3: number@scalar) Arg schema: arg1{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg2{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false}; arg3{kinds=number,required=true,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=false} Caps: PURE [formualizer-docgen:schema:end]
fn name(&self) -> &'static str
fn min_args(&self) -> usize
fn arg_schema(&self) -> &'static [ArgSchema]
Sourcefn eval<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn eval<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
fn namespace(&self) -> &'static str
fn variadic(&self) -> bool
fn volatile(&self) -> bool
Sourcefn aliases(&self) -> &'static [&'static str]
fn aliases(&self) -> &'static [&'static str]
fn function_salt(&self) -> u64
Sourcefn eval_reference<'a, 'b, 'c>(
&self,
_args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Option<Result<ReferenceType, ExcelError>>
fn eval_reference<'a, 'b, 'c>( &self, _args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Option<Result<ReferenceType, ExcelError>>
Sourcefn dispatch<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn dispatch<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>