pub struct TextBeforeFn;Trait Implementations
Sourceimpl Debug for TextBeforeFn
impl Debug for TextBeforeFn
Sourceimpl Function for TextBeforeFn
Returns text that appears before a delimiter.
impl Function for TextBeforeFn
Returns text that appears before a delimiter.
Remarks
- Delimiter matching is case-sensitive.
instance_numdefaults to1; negative instances search from the end.instance_num=0or empty delimiter returns#VALUE!.- If requested delimiter occurrence is not found, returns
#N/A.
Examples
title: "Text before first delimiter"
formula: '=TEXTBEFORE("a-b-c", "-")'
expected: "a"title: "Text before last delimiter"
formula: '=TEXTBEFORE("a-b-c", "-", -1)'
expected: "a-b"related:
- TEXTAFTER
- FIND
- SEARCH
faq:
- q: "What happens when the delimiter is missing?"
a: "TEXTBEFORE returns #N/A when the requested delimiter occurrence is not found."[formualizer-docgen:schema:start] Name: TEXTBEFORE Type: TextBeforeFn Min args: 2 Max args: 3 Variadic: false Signature: TEXTBEFORE(arg1: any@scalar, arg2: any@scalar, arg3?: number@scalar) Arg schema: arg1{kinds=any,required=true,shape=scalar,by_ref=false,coercion=None,max=None,repeating=None,default=false}; arg2{kinds=any,required=true,shape=scalar,by_ref=false,coercion=None,max=None,repeating=None,default=false}; arg3{kinds=number,required=false,shape=scalar,by_ref=false,coercion=NumberLenientText,max=None,repeating=None,default=true} Caps: PURE [formualizer-docgen:schema:end]
fn name(&self) -> &'static str
fn min_args(&self) -> usize
fn arg_schema(&self) -> &'static [ArgSchema]
Sourcefn eval<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
_: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn eval<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], _: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
The unified evaluation path. Read more
fn namespace(&self) -> &'static str
fn variadic(&self) -> bool
fn volatile(&self) -> bool
Sourcefn aliases(&self) -> &'static [&'static str]
fn aliases(&self) -> &'static [&'static str]
Optional list of additional alias names (case-insensitive) that should resolve to this
function. Default: empty slice. Implementors can override to expose legacy names.
Returned slice must have ’static lifetime (typically a static array reference).
fn function_salt(&self) -> u64
Sourcefn eval_reference<'a, 'b, 'c>(
&self,
_args: &'c [ArgumentHandle<'a, 'b>],
_ctx: &dyn FunctionContext<'b>,
) -> Option<Result<ReferenceType, ExcelError>>
fn eval_reference<'a, 'b, 'c>( &self, _args: &'c [ArgumentHandle<'a, 'b>], _ctx: &dyn FunctionContext<'b>, ) -> Option<Result<ReferenceType, ExcelError>>
Optional reference result path. Only called by the interpreter/engine
when the callsite expects a reference (e.g., range combinators, by-ref
argument positions, or spill sources). Read more
Sourcefn dispatch<'a, 'b, 'c>(
&self,
args: &'c [ArgumentHandle<'a, 'b>],
ctx: &dyn FunctionContext<'b>,
) -> Result<CalcValue<'b>, ExcelError>
fn dispatch<'a, 'b, 'c>( &self, args: &'c [ArgumentHandle<'a, 'b>], ctx: &dyn FunctionContext<'b>, ) -> Result<CalcValue<'b>, ExcelError>
Dispatch to the unified evaluation path with automatic argument validation.