#[non_exhaustive]pub struct EngineBaselineStats {Show 21 fields
pub graph_vertex_count: usize,
pub graph_formula_vertex_count: usize,
pub graph_edge_count: usize,
pub dirty_vertex_count: usize,
pub evaluation_vertex_count: usize,
pub formula_ast_root_count: usize,
pub formula_ast_node_count: usize,
pub staged_formula_count: usize,
pub formula_plane_active_span_count: usize,
pub formula_plane_producer_result_entries: usize,
pub formula_plane_consumer_read_entries: usize,
pub formula_plane_mixed_topology_cache_builds: u64,
pub formula_plane_mixed_topology_cache_hits: u64,
pub formula_plane_mixed_topology_cache_overflows: u64,
pub formula_plane_dirty_pending_events: usize,
pub formula_plane_dirty_region_events_recorded: u64,
pub formula_plane_dirty_span_region_events_recorded: u64,
pub formula_plane_dirty_whole_span_seeds_recorded: u64,
pub formula_plane_dirty_global_invalidations: u64,
pub formula_plane_structural_span_candidates: u64,
pub formula_plane_cycle_member_span_demotions: u64,
}Expand description
Read-only engine counters used by benchmark/instrumentation tooling.
These counters are deliberately observational: collecting them must not mutate engine state or alter formula evaluation semantics.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.graph_vertex_count: usizegraph_formula_vertex_count: usizegraph_edge_count: usizedirty_vertex_count: usizeevaluation_vertex_count: usizeformula_ast_root_count: usizeformula_ast_node_count: usizestaged_formula_count: usizeformula_plane_active_span_count: usizeformula_plane_producer_result_entries: usizeformula_plane_consumer_read_entries: usizeformula_plane_mixed_topology_cache_builds: u64formula_plane_mixed_topology_cache_hits: u64formula_plane_mixed_topology_cache_overflows: u64formula_plane_dirty_pending_events: usizeformula_plane_dirty_region_events_recorded: u64formula_plane_dirty_span_region_events_recorded: u64formula_plane_dirty_whole_span_seeds_recorded: u64formula_plane_dirty_global_invalidations: u64formula_plane_structural_span_candidates: u64formula_plane_cycle_member_span_demotions: u64Number of spans demoted to legacy because a member participated in a statically-cyclic SCC (gotcha G8, refs #112).