Module reference_adjuster

Module reference_adjuster 

Structs

MoveReferenceAdjuster
Helper for adjusting references to moved ranges. This is used when a block of cells is moved; any formula references to cells fully inside the source rectangle are translated to the destination.
ReferenceAdjuster
Centralized reference adjustment logic for structural changes
RelativeReferenceAdjuster
Helper for adjusting references when copying/moving ranges

Enums

ShiftOperation