pub struct MoveReferenceAdjuster { /* private fields */ }Expand description
Helper for adjusting references to moved ranges. This is used when a block of cells is moved; any formula references to cells fully inside the source rectangle are translated to the destination.
Implementations
Sourceimpl MoveReferenceAdjuster
impl MoveReferenceAdjuster
pub fn new( from_sheet_id: SheetId, from_sheet_name: String, from_start_row: u32, from_start_col: u32, from_end_row: u32, from_end_col: u32, to_sheet_id: SheetId, to_sheet_name: String, row_offset: i32, col_offset: i32, ) -> Self
pub fn adjust_if_references( &self, formula: &ASTNode, formula_sheet_id: SheetId, ) -> Option<ASTNode>