#[non_exhaustive]pub struct TraceGraph {
pub stamp: StateStamp,
pub direction: TraceDirection,
pub roots: Vec<TraceNodeId>,
pub nodes: Vec<TraceNode>,
pub truncation: TruncationReport,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.stamp: StateStampdirection: TraceDirectionroots: Vec<TraceNodeId>One response-local node id per requested root, in request order. Duplicate roots retain repeated ids while sharing one materialized node.
nodes: Vec<TraceNode>truncation: TruncationReportTrait Implementations
Sourceimpl Clone for TraceGraph
impl Clone for TraceGraph
Sourcefn clone(&self) -> TraceGraph
fn clone(&self) -> TraceGraph
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TraceGraph
impl Debug for TraceGraph
Sourceimpl PartialEq for TraceGraph
impl PartialEq for TraceGraph
impl StructuralPartialEq for TraceGraph