pub struct IntervalTree<T: Clone + Eq + Hash> { /* private fields */ }Expand description
B-Tree based implementation of the interval index.
Implementations
Sourceimpl<T: Clone + Eq + Hash> IntervalTree<T>
impl<T: Clone + Eq + Hash> IntervalTree<T>
pub fn new() -> Self
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
Sourcepub fn get_mut(&mut self, low: u32, high: u32) -> Option<&mut HashSet<T>>
pub fn get_mut(&mut self, low: u32, high: u32) -> Option<&mut HashSet<T>>
Get a mutable reference to the values for an exact interval match. Required by the Entry API.
Sourcepub fn insert(&mut self, low: u32, high: u32, value: T)
pub fn insert(&mut self, low: u32, high: u32, value: T)
Insert a value for the given interval [low, high]
pub fn query(&self, q_low: u32, q_high: u32) -> Vec<(u32, u32, HashSet<T>)>
pub fn remove(&mut self, low: u32, high: u32, value: &T) -> bool
pub fn entry(&mut self, low: u32, high: u32) -> BTreeEntry<'_, T>
Sourcepub fn bulk_build_points(&mut self, items: Vec<(u32, HashSet<T>)>)
pub fn bulk_build_points(&mut self, items: Vec<(u32, HashSet<T>)>)
Bulk build optimization for a collection of point intervals [x,x].