pub struct AdmissionResourceBudget {
pub graph_vertex_hard_limit: Option<usize>,
pub graph_edge_hard_limit: Option<usize>,
pub materialization_cells: Option<u64>,
pub materialized_graph_bytes: Option<u64>,
}Fields
graph_vertex_hard_limit: Option<usize>Hard cap on the exact final graph vertex count at common mutation preflight.
graph_edge_hard_limit: Option<usize>Hard cap on the exact final graph edge count at common mutation preflight.
materialization_cells: Option<u64>Hard cap on formula cells actually materialized into the legacy graph.
materialized_graph_bytes: Option<u64>Hard cap on bytes attributed to newly materialized graph vertices and edges.