pub struct Schedule {
pub units: Vec<ScheduleUnit>,
pub cycles: Vec<Vec<VertexId>>,
pub layers: Vec<Layer>,
}Fields
units: Vec<ScheduleUnit>Canonical walk order: condensation order over the dependency graph.
Every Cycle unit appears after all units containing its external
dependencies and before all units containing its external dependents.
cycles: Vec<Vec<VertexId>>All cyclic SCCs (same contents as before units existed), for
consumers that only need the set of cycles.
layers: Vec<Layer>The Layer units in order, for consumers that only walk layers.
Implementations