pub struct TombstoneRegistry {
pub pending_references: HashMap<String, Vec<VertexId>>,
}Fields
pending_references: HashMap<String, Vec<VertexId>>Implementations
Sourceimpl TombstoneRegistry
impl TombstoneRegistry
Sourcepub fn add_orphan(&mut self, sheet_name: String, vertex_id: VertexId)
pub fn add_orphan(&mut self, sheet_name: String, vertex_id: VertexId)
Record that a vertex is waiting for a specific sheet name to appear.
Sourcepub fn take_orphans(&mut self, sheet_name: &str) -> Vec<VertexId>
pub fn take_orphans(&mut self, sheet_name: &str) -> Vec<VertexId>
Retrieve and remove all vertices waiting for a specific sheet name.