pub struct CandidateFormulaRun {
pub template_id: String,
pub sheet: String,
pub orientation: CandidateRunOrientation,
pub fixed_index: u32,
pub start_index: u32,
pub end_index: u32,
pub len: u64,
pub partitions_touched: u64,
}Expand description
Passive candidate run summary for a dependent formula placement.
Fields
template_id: Stringsheet: Stringorientation: CandidateRunOrientationfixed_index: u32Row for row runs, column for column runs.
start_index: u32Column start for row runs, row start for column runs.
end_index: u32Column end for row runs, row end for column runs.
len: u64partitions_touched: u64Trait Implementations
Sourceimpl Clone for CandidateFormulaRun
impl Clone for CandidateFormulaRun
Sourcefn clone(&self) -> CandidateFormulaRun
fn clone(&self) -> CandidateFormulaRun
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CandidateFormulaRun
impl Debug for CandidateFormulaRun
impl Eq for CandidateFormulaRun
Sourceimpl PartialEq for CandidateFormulaRun
impl PartialEq for CandidateFormulaRun
Sourcefn eq(&self, other: &CandidateFormulaRun) -> bool
fn eq(&self, other: &CandidateFormulaRun) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CandidateFormulaRun