pub struct VirtualProviderVersion {
pub fingerprint_hi: u64,
pub fingerprint_lo: u64,
}Expand description
Provider-supplied version token for immutable or versioned virtual data.
Fields
fingerprint_hi: u64fingerprint_lo: u64Trait Implementations
Sourceimpl Clone for VirtualProviderVersion
impl Clone for VirtualProviderVersion
Sourcefn clone(&self) -> VirtualProviderVersion
fn clone(&self) -> VirtualProviderVersion
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VirtualProviderVersion
Sourceimpl Debug for VirtualProviderVersion
impl Debug for VirtualProviderVersion
impl Eq for VirtualProviderVersion
Sourceimpl Hash for VirtualProviderVersion
impl Hash for VirtualProviderVersion
Sourceimpl PartialEq for VirtualProviderVersion
impl PartialEq for VirtualProviderVersion
Sourcefn eq(&self, other: &VirtualProviderVersion) -> bool
fn eq(&self, other: &VirtualProviderVersion) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for VirtualProviderVersion