FnCaps

Struct FnCaps 

pub struct FnCaps(/* private fields */);
Describes the capabilities and properties of a function.

This allows the engine to select optimal evaluation paths (e.g., vectorized, parallel, GPU) and to enforce semantic contracts at compile time.

Implementations

Source

impl FnCaps

pub const PURE: Self

The function always produces the same output for the same input and has no side effects. This is the default for most functions.

pub const VOLATILE: Self

The function’s output can change even with the same inputs (e.g., RAND(), NOW()). Volatile functions are re-evaluated on every sheet change.

pub const REDUCTION: Self

The function reduces a range of inputs to a single value (e.g., SUM, AVERAGE).

pub const ELEMENTWISE: Self

The function operates on each element of its input ranges independently (e.g., SIN, ABS).

pub const WINDOWED: Self

The function operates on a sliding window over its input (e.g., MOVING_AVERAGE).

pub const LOOKUP: Self

The function performs a lookup or search operation (e.g., VLOOKUP).

pub const NUMERIC_ONLY: Self

The function primarily operates on numbers. The engine can prepare optimized numeric stripes (&[f64]) for it.

pub const BOOL_ONLY: Self

The function primarily operates on booleans.

pub const SIMD_OK: Self

The function has an implementation suitable for SIMD vectorization.

pub const STREAM_OK: Self

The function can process input as a stream, without materializing the entire range in memory.

pub const GPU_OK: Self

The function has a GPU-accelerated implementation.

pub const RETURNS_REFERENCE: Self

The function can return a reference (to a cell/range/table) when evaluated in a reference context. When used in a value context, engines may materialize the reference to a LiteralValue.

pub const SHORT_CIRCUIT: Self

The function enforces left-to-right evaluation and early-exit semantics. The planner must not evaluate arguments in parallel nor reorder them.

pub const PARALLEL_ARGS: Self

It is safe and potentially profitable to evaluate arguments in parallel. The engine should still fold results in argument order for determinism.

pub const PARALLEL_CHUNKS: Self

It is safe to chunk and process input windows in parallel (e.g., SUMIFS). It is safe to chunk and process input windows in parallel (e.g., SUMIFS).

pub const DYNAMIC_DEPENDENCY: Self

Function has dynamic dependencies determined at runtime (e.g. INDIRECT, OFFSET)

Source

impl FnCaps

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u16

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u16) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u16) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u16) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl FnCaps

pub const fn iter(&self) -> Iter<FnCaps>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<FnCaps>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.