pub struct ReferenceInfo {
pub first_sheet_index: Option<usize>,
pub sheet_count: Option<usize>,
pub first_cell: Option<CellRef>,
}Fields
first_sheet_index: Option<usize>Excel-style 1-based index of the first sheet covered by the reference.
sheet_count: Option<usize>Number of sheets covered by the reference (1 for ordinary references, N for 3D refs).
first_cell: Option<CellRef>Top-left / first cell addressed by the reference, when it resolves to a concrete cell.