pub struct WorkdayFn;Expand description
WORKDAY(start_date, days, [holidays]) - Returns a date that is a specified number of working days away
NOTE: The holidays parameter is currently accepted but not implemented. Holiday values passed to this function will be silently ignored.