pub struct EngineBaselineStats {
pub graph_vertex_count: usize,
pub graph_formula_vertex_count: usize,
pub graph_edge_count: usize,
pub dirty_vertex_count: usize,
pub evaluation_vertex_count: usize,
pub formula_ast_root_count: usize,
pub formula_ast_node_count: usize,
pub staged_formula_count: usize,
pub formula_plane_active_span_count: usize,
pub formula_plane_producer_result_entries: usize,
pub formula_plane_consumer_read_entries: usize,
pub formula_plane_cycle_member_span_demotions: u64,
}Expand description
Read-only engine counters used by benchmark/instrumentation tooling.
These counters are deliberately observational: collecting them must not mutate engine state or alter formula evaluation semantics.
Fields
graph_vertex_count: usizegraph_formula_vertex_count: usizegraph_edge_count: usizedirty_vertex_count: usizeevaluation_vertex_count: usizeformula_ast_root_count: usizeformula_ast_node_count: usizestaged_formula_count: usizeformula_plane_active_span_count: usizeformula_plane_producer_result_entries: usizeformula_plane_consumer_read_entries: usizeformula_plane_cycle_member_span_demotions: u64Number of spans demoted to legacy because a member participated in a statically-cyclic SCC (gotcha G8, refs #112).