Structs
- Move
Reference Adjuster - Helper for adjusting references to moved ranges. This is used when a block of cells is moved; any formula references to cells fully inside the source rectangle are translated to the destination.
- Reference
Adjuster - Centralized reference adjustment logic for structural changes
- Relative
Reference Adjuster - Helper for adjusting references when copying/moving ranges