#[non_exhaustive]pub struct EvaluationResourceBaselineStats {Show 35 fields
pub last_request_id: u64,
pub requests_started: u64,
pub requests_succeeded: u64,
pub requests_cancelled: u64,
pub requests_errored: u64,
pub staged_selected_total: u64,
pub topology_cache_hits: u64,
pub topology_cache_builds: u64,
pub topology_cache_skips: u64,
pub topology_cache_skip_streak_current: u64,
pub topology_cache_skip_streak_max: u64,
pub topology_exact_passes_total: u64,
pub topology_native_disk_bytes_total: u64,
pub topology_candidate_cap_hits: u64,
pub topology_edge_cap_hits: u64,
pub topology_byte_cap_hits: u64,
pub topology_candidates_observed_total: u64,
pub topology_edges_observed_total: u64,
pub topology_retained_bytes_observed_max: u64,
pub fallback_materialized_cells_total: u64,
pub cycle_materialized_cells_total: u64,
pub dirty_leases_acknowledged: u64,
pub dirty_leases_retained_on_cancel: u64,
pub dirty_leases_retained_on_error: u64,
pub ledger_retained_peak: u64,
pub ledger_scratch_peak: u64,
pub ledger_work_charged_total: u64,
pub ledger_deadline_checkpoints: u64,
pub ledger_exhaustions: u64,
pub last_ledger_exhaustion: Option<ResourceExhaustionReason>,
pub total_request_ns: u64,
pub staged_prepare_ns: u64,
pub topology_ns: u64,
pub materialization_ns: u64,
pub evaluation_ns: u64,
}Expand description
Cumulative observational counters since engine creation or the last explicit telemetry reset. Resetting these counters never resets the monotonic request ID sequence.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.last_request_id: u64requests_started: u64requests_succeeded: u64requests_cancelled: u64requests_errored: u64staged_selected_total: u64topology_cache_hits: u64topology_cache_builds: u64topology_cache_skips: u64topology_cache_skip_streak_current: u64topology_cache_skip_streak_max: u64topology_exact_passes_total: u64topology_native_disk_bytes_total: u64topology_candidate_cap_hits: u64topology_edge_cap_hits: u64topology_byte_cap_hits: u64topology_candidates_observed_total: u64topology_edges_observed_total: u64topology_retained_bytes_observed_max: u64fallback_materialized_cells_total: u64cycle_materialized_cells_total: u64dirty_leases_acknowledged: u64dirty_leases_retained_on_cancel: u64dirty_leases_retained_on_error: u64ledger_retained_peak: u64ledger_scratch_peak: u64ledger_work_charged_total: u64ledger_deadline_checkpoints: u64ledger_exhaustions: u64last_ledger_exhaustion: Option<ResourceExhaustionReason>total_request_ns: u64staged_prepare_ns: u64topology_ns: u64materialization_ns: u64evaluation_ns: u64Trait Implementations
Sourceimpl Clone for EvaluationResourceBaselineStats
impl Clone for EvaluationResourceBaselineStats
Sourcefn clone(&self) -> EvaluationResourceBaselineStats
fn clone(&self) -> EvaluationResourceBaselineStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for EvaluationResourceBaselineStats
Sourceimpl Default for EvaluationResourceBaselineStats
impl Default for EvaluationResourceBaselineStats
Sourcefn default() -> EvaluationResourceBaselineStats
fn default() -> EvaluationResourceBaselineStats
Returns the “default value” for a type. Read more
impl Eq for EvaluationResourceBaselineStats
impl StructuralPartialEq for EvaluationResourceBaselineStats