pub struct WorkbookLoadLimits {
pub max_sheet_rows: u32,
pub max_sheet_cols: u32,
pub max_sheet_logical_cells: u64,
pub sparse_sheet_cell_threshold: u64,
pub max_sparse_cell_ratio: u64,
}Expand description
Workbook ingest limits applied by loader backends before they materialize large sheets.
Fields
max_sheet_rows: u32Hard cap for declared/logical sheet rows.
max_sheet_cols: u32Hard cap for declared/logical sheet columns.
max_sheet_logical_cells: u64Hard cap for the rectangular logical area a backend may materialize.
sparse_sheet_cell_threshold: u64Sparse-sheet checks only trigger once a sheet reaches this many logical cells.
max_sparse_cell_ratio: u64Maximum allowed logical-to-populated-cell ratio once the sparse threshold is crossed.